@@ -19,6 +19,9 @@ __all__ = [
     'to_html',
     'config2file',
     'text',
+    'icon',
+    'icon_fromfile',
+    'row',
 ]
 
 box = app.box
@@ -34,6 +37,9 @@ tabs = app.tabs
 text = app.text
 plotly = app.plotly
 fns = app.Fns
+icon_fromfile = app.icon_fromfile
+icon = app.icon
+row=app.row
 
 # v = FnContext()
 
