@@ -1,6 +1,6 @@
-from typing import Union,Dict,List
+from typing import Union, Dict, List
 from pyvisflow.core.components.components import Component
-from pyvisflow.core.props import TypePropInfo,StrTypePropInfo,SubscriptableTypePropInfo, NumberTypePropInfo, BoolTypePropInfo
+from pyvisflow.core.props import TypePropInfo, StrTypePropInfo, SubscriptableTypePropInfo, NumberTypePropInfo, BoolTypePropInfo
 from pyvisflow.models.TComponent import TComponentType
 from pyvisflow.core.props import *
 
@@ -10,36 +10,12 @@ class _Select(Component):
     Select 选择器
 当选项过多时，使用下拉菜单展示并选择内容
     '''
-
     def __init__(self) -> None:
         super().__init__('select', TComponentType.builtIn)
 
     def _ex_get_react_data(self):
         return super()._ex_get_react_data()
 
-
-    @property
-    def values(self):
-        '''
-        可选值：— \n
-        选中项绑定值
-        '''
-
-        
-        p = self.get_prop('values')
-        return SubscriptableTypePropInfo[int,NumberTypePropInfo](p)
-
-        
-
-
-    @values.setter
-    def values(self, value: Union[SubscriptableTypePropInfo[int,NumberTypePropInfo],List[int]]):
-        '''
-        可选值：— \n
-        选中项绑定值
-        '''
-        self.set_prop('values', value)
-
     @property
     def multiple(self):
         '''
@@ -47,15 +23,11 @@ class _Select(Component):
         是否多选
         '''
 
-        
         p = self.get_prop('multiple')
         return BoolTypePropInfo(p)
 
-        
-
-
     @multiple.setter
-    def multiple(self, value: Union[BoolTypePropInfo,bool]):
+    def multiple(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：— \n
         是否多选
@@ -69,15 +41,11 @@ class _Select(Component):
         是否禁用
         '''
 
-        
         p = self.get_prop('disabled')
         return BoolTypePropInfo(p)
 
-        
-
-
     @disabled.setter
-    def disabled(self, value: Union[BoolTypePropInfo,bool]):
+    def disabled(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：— \n
         是否禁用
@@ -91,15 +59,11 @@ class _Select(Component):
         作为 value 唯一标识的键名，绑定值为对象类型时必填
         '''
 
-        
         p = self.get_prop('value-key')
         return StrTypePropInfo(p)
 
-        
-
-
     @value_key.setter
-    def value_key(self, value: Union[StrTypePropInfo,str]):
+    def value_key(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：— \n
         作为 value 唯一标识的键名，绑定值为对象类型时必填
@@ -113,15 +77,11 @@ class _Select(Component):
         输入框尺寸
         '''
 
-        
         p = self.get_prop('size')
         return StrTypePropInfo(p)
 
-        
-
-
     @size.setter
-    def size(self, value: Union[StrTypePropInfo,str]):
+    def size(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：large/default/small \n
         输入框尺寸
@@ -135,15 +95,11 @@ class _Select(Component):
         是否可以清空选项
         '''
 
-        
         p = self.get_prop('clearable')
         return BoolTypePropInfo(p)
 
-        
-
-
     @clearable.setter
-    def clearable(self, value: Union[BoolTypePropInfo,bool]):
+    def clearable(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：large/default/small \n
         是否可以清空选项
@@ -157,15 +113,11 @@ class _Select(Component):
         多选时是否将选中值按文字的形式展示
         '''
 
-        
         p = self.get_prop('collapse-tags')
         return BoolTypePropInfo(p)
 
-        
-
-
     @collapse_tags.setter
-    def collapse_tags(self, value: Union[BoolTypePropInfo,bool]):
+    def collapse_tags(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：large/default/small \n
         多选时是否将选中值按文字的形式展示
@@ -179,15 +131,11 @@ class _Select(Component):
         多选时用户最多可以选择的项目数， 为 0 则不限制
         '''
 
-        
         p = self.get_prop('multiple-limit')
         return NumberTypePropInfo(p)
 
-        
-
-
     @multiple_limit.setter
-    def multiple_limit(self, value: Union[NumberTypePropInfo,int]):
+    def multiple_limit(self, value: Union[NumberTypePropInfo, int]):
         '''
         可选值：large/default/small \n
         多选时用户最多可以选择的项目数， 为 0 则不限制
@@ -201,15 +149,11 @@ class _Select(Component):
         多选框的输入框的原生 name 属性
         '''
 
-        
         p = self.get_prop('name')
         return StrTypePropInfo(p)
 
-        
-
-
     @name.setter
-    def name(self, value: Union[StrTypePropInfo,str]):
+    def name(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：large/default/small \n
         多选框的输入框的原生 name 属性
@@ -223,15 +167,11 @@ class _Select(Component):
         Tooltip theme, built-in theme: dark / light
         '''
 
-        
         p = self.get_prop('effect')
         return StrTypePropInfo(p)
 
-        
-
-
     @effect.setter
-    def effect(self, value: Union[StrTypePropInfo,str]):
+    def effect(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：string \n
         Tooltip theme, built-in theme: dark / light
@@ -245,15 +185,11 @@ class _Select(Component):
         ‎选择输入的自动完成属性‎
         '''
 
-        
         p = self.get_prop('autocomplete')
         return StrTypePropInfo(p)
 
-        
-
-
     @autocomplete.setter
-    def autocomplete(self, value: Union[StrTypePropInfo,str]):
+    def autocomplete(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：string \n
         ‎选择输入的自动完成属性‎
@@ -267,15 +203,11 @@ class _Select(Component):
         ‎占 位 符‎
         '''
 
-        
         p = self.get_prop('placeholder')
         return StrTypePropInfo(p)
 
-        
-
-
     @placeholder.setter
-    def placeholder(self, value: Union[StrTypePropInfo,str]):
+    def placeholder(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：string \n
         ‎占 位 符‎
@@ -289,15 +221,11 @@ class _Select(Component):
         ‎选择是否可过滤‎
         '''
 
-        
         p = self.get_prop('filterable')
         return BoolTypePropInfo(p)
 
-        
-
-
     @filterable.setter
-    def filterable(self, value: Union[BoolTypePropInfo,bool]):
+    def filterable(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：string \n
         ‎选择是否可过滤‎
@@ -311,15 +239,11 @@ class _Select(Component):
         ‎是否允许创建新项目。要使用此，必须为 true‎filterable
         '''
 
-        
         p = self.get_prop('allow-create')
         return BoolTypePropInfo(p)
 
-        
-
-
     @allow_create.setter
-    def allow_create(self, value: Union[BoolTypePropInfo,bool]):
+    def allow_create(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：string \n
         ‎是否允许创建新项目。要使用此，必须为 true‎filterable
@@ -333,15 +257,11 @@ class _Select(Component):
         ‎是否从服务器加载选项‎
         '''
 
-        
         p = self.get_prop('remote')
         return BoolTypePropInfo(p)
 
-        
-
-
     @remote.setter
-    def remote(self, value: Union[BoolTypePropInfo,bool]):
+    def remote(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：string \n
         ‎是否从服务器加载选项‎
@@ -355,15 +275,11 @@ class _Select(Component):
         ‎选择是否正在从服务器加载数据‎
         '''
 
-        
         p = self.get_prop('loading')
         return BoolTypePropInfo(p)
 
-        
-
-
     @loading.setter
-    def loading(self, value: Union[BoolTypePropInfo,bool]):
+    def loading(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：string \n
         ‎选择是否正在从服务器加载数据‎
@@ -377,15 +293,11 @@ class _Select(Component):
         ‎从服务器加载数据时显示的文本‎
         '''
 
-        
         p = self.get_prop('loading-text')
         return StrTypePropInfo(p)
 
-        
-
-
     @loading_text.setter
-    def loading_text(self, value: Union[StrTypePropInfo,str]):
+    def loading_text(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：string \n
         ‎从服务器加载数据时显示的文本‎
@@ -399,15 +311,11 @@ class _Select(Component):
         ‎当没有数据与过滤查询匹配时显示的文本，也可以使用 slot‎empty
         '''
 
-        
         p = self.get_prop('no-match-text')
         return StrTypePropInfo(p)
 
-        
-
-
     @no_match_text.setter
-    def no_match_text(self, value: Union[StrTypePropInfo,str]):
+    def no_match_text(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：string \n
         ‎当没有数据与过滤查询匹配时显示的文本，也可以使用 slot‎empty
@@ -421,15 +329,11 @@ class _Select(Component):
         ‎显示文本时没有选项，也可以使用插槽‎empty
         '''
 
-        
         p = self.get_prop('no-data-text')
         return StrTypePropInfo(p)
 
-        
-
-
     @no_data_text.setter
-    def no_data_text(self, value: Union[StrTypePropInfo,str]):
+    def no_data_text(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：string \n
         ‎显示文本时没有选项，也可以使用插槽‎empty
@@ -443,15 +347,11 @@ class _Select(Component):
         ‎"选择"下拉列表的自定义类名‎
         '''
 
-        
         p = self.get_prop('popper-class')
         return StrTypePropInfo(p)
 
-        
-
-
     @popper_class.setter
-    def popper_class(self, value: Union[StrTypePropInfo,str]):
+    def popper_class(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：string \n
         ‎"选择"下拉列表的自定义类名‎
@@ -465,15 +365,11 @@ class _Select(Component):
         ‎何时 为 true，是否在选择选项后保留当前关键字‎multiplefilter
         '''
 
-        
         p = self.get_prop('reserve-keyword')
         return BoolTypePropInfo(p)
 
-        
-
-
     @reserve_keyword.setter
-    def reserve_keyword(self, value: Union[BoolTypePropInfo,bool]):
+    def reserve_keyword(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：string \n
         ‎何时 为 true，是否在选择选项后保留当前关键字‎multiplefilter
@@ -487,15 +383,11 @@ class _Select(Component):
         ‎在输入键上选择第一个匹配选项。与 或 一起使用‎filterableremote
         '''
 
-        
         p = self.get_prop('default-first-option')
         return BoolTypePropInfo(p)
 
-        
-
-
     @default_first_option.setter
-    def default_first_option(self, value: Union[BoolTypePropInfo,bool]):
+    def default_first_option(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：string \n
         ‎在输入键上选择第一个匹配选项。与 或 一起使用‎filterableremote
@@ -509,15 +401,11 @@ class _Select(Component):
         ‎选择下拉列表是否传送到正文‎
         '''
 
-        
         p = self.get_prop('teleported')
         return BoolTypePropInfo(p)
 
-        
-
-
     @teleported.setter
-    def teleported(self, value: Union[BoolTypePropInfo,bool]):
+    def teleported(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：true / false \n
         ‎选择下拉列表是否传送到正文‎
@@ -531,15 +419,11 @@ class _Select(Component):
         ‎当选择下拉列表处于非活动状态并且是 时，选择下拉列表将被销毁‎persistentfalse
         '''
 
-        
         p = self.get_prop('persistent')
         return BoolTypePropInfo(p)
 
-        
-
-
     @persistent.setter
-    def persistent(self, value: Union[BoolTypePropInfo,bool]):
+    def persistent(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：true / false \n
         ‎当选择下拉列表处于非活动状态并且是 时，选择下拉列表将被销毁‎persistentfalse
@@ -553,15 +437,11 @@ class _Select(Component):
         ‎对于不可过滤的 Select，此属性决定在输入聚焦时是否弹出选项菜单‎
         '''
 
-        
         p = self.get_prop('automatic-dropdown')
         return BoolTypePropInfo(p)
 
-        
-
-
     @automatic_dropdown.setter
-    def automatic_dropdown(self, value: Union[BoolTypePropInfo,bool]):
+    def automatic_dropdown(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：true / false \n
         ‎对于不可过滤的 Select，此属性决定在输入聚焦时是否弹出选项菜单‎
@@ -575,15 +455,11 @@ class _Select(Component):
         ‎下拉列表的宽度是否与输入相同‎
         '''
 
-        
         p = self.get_prop('fit-input-width')
         return BoolTypePropInfo(p)
 
-        
-
-
     @fit_input_width.setter
-    def fit_input_width(self, value: Union[BoolTypePropInfo,bool]):
+    def fit_input_width(self, value: Union[BoolTypePropInfo, bool]):
         '''
         可选值：true / false \n
         ‎下拉列表的宽度是否与输入相同‎
@@ -597,15 +473,11 @@ class _Select(Component):
         ‎标记类型‎
         '''
 
-        
         p = self.get_prop('tag-type')
         return StrTypePropInfo(p)
 
-        
-
-
     @tag_type.setter
-    def tag_type(self, value: Union[StrTypePropInfo,str]):
+    def tag_type(self, value: Union[StrTypePropInfo, str]):
         '''
         可选值：success/info/warning/danger \n
         ‎标记类型‎
