@@ -6,6 +6,7 @@ import pandas as pd
 from pyvisflow.core.components.components import Component
 from pyvisflow.core.components.dataTable import DataTable
 from pyvisflow.core.components.echart import EChart
+from pyvisflow.core.components.icon import Icon
 from pyvisflow.core.components.input import Input
 from pyvisflow.core.components.inputNumber import InputNumber
 from pyvisflow.core.components.plotly import Plotly
@@ -36,70 +37,108 @@ class BoxContainer(Container):
         super().__init__('box')
         self._spec = sepc
         self._on_before_data_fn = lambda data: data
+        self._on_before_add_child_fn = BoxContainer.__default_on_before_add_child_fn
+
+    @staticmethod
+    def __default_on_before_add_child_fn(cp: Component):
+        pass
 
     def box(self, ):
         cp = BoxContainer()
         cp._on_before_data_fn = self._on_before_data_fn
+        cp._on_before_add_child_fn = self._on_before_add_child_fn
+
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
-    def text(self,value:str):
+    def row(self, ):
+        cp = Row()
+        cp._on_before_data_fn = self._on_before_data_fn
+        self._on_before_add_child_fn(cp)
+        self.add_child(cp)
+        return cp
+
+    def icon(self, svg: str, size: str):
+        cp = Icon(svg, size)
+        self._on_before_add_child_fn(cp)
+        self.add_child(cp)
+        return cp
+
+    def icon_fromfile(self, file: str, size: str):
+        with open(file, 'r', encoding='utf8') as f:
+            return self.icon(f.read(), size)
+
+    def text(self, value: str):
         cp = Text(value)
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
     def dataTable(self, dataframe: pd.DataFrame, page_size=5):
         cp = DataTable(self._on_before_data_fn(dataframe))
         cp.page_size = page_size
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
     def tabs(self, names: Union[Iterable[str], Dict[str, str]]):
         cp = tabs.Tabs(names)
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
 
         for box in cp.boxes:
             box._on_before_data_fn = self._on_before_data_fn
+            box._on_before_add_child_fn = self._on_before_add_child_fn
 
         return cp
 
     def plotly(self):
         cp = Plotly()
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
     def cols(self, spec: Union[int, List[int]]):
         cp = ColumnsContainer(spec)
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
 
         for box in cp.boxes:
             box._on_before_data_fn = self._on_before_data_fn
+            box._on_before_add_child_fn = self._on_before_add_child_fn
 
         return cp.boxes
 
     def input(self, value=''):
         cp = Input(value)
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
     def inputNumber(self, value=0):
         cp = InputNumber(value)
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
     def select(self, options: Iterable[str]):
         cp = Select(options)
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
     def echart(self, data: pd.DataFrame):
         cp = EChart(self._on_before_data_fn(data))
+        self._on_before_add_child_fn(cp)
         self.add_child(cp)
         return cp
 
     def markdown(self, md: str, **prop_mapping: TypePropInfo):
         layout = MarkdownLayout(md, prop_mapping)
+
         for cp in layout.parse_markdown():
+            self._on_before_add_child_fn(cp)
             self.add_child(cp)
         return layout
 
@@ -141,4 +180,25 @@ class ColumnsContainer(Container):
         return data
 
 
+class Row(BoxContainer):
+    def __init__(self) -> None:
+        super().__init__()
+        self._tag='row'
+
+    @property
+    def isWrap(self):
+        '''
+
+        '''
+
+        p = self.get_prop('isWrap')
+        return BoolTypePropInfo(p)
+
+    @isWrap.setter
+    def isWrap(self, value: Union[BoolTypePropInfo, bool]):
+        '''
+        '''
+        self.set_prop('isWrap', value)
+
+
 import pyvisflow.core.components.tabs as tabs
\ No newline at end of file
