@@ -17,14 +17,24 @@ class Select(_Select):
         super().__init__()
         options = list(options)
 
-        self._options = [
-            TSelectOption(label=value, value=idx)
-            for idx, value in enumerate(options)
-        ]
+        self._options = options
 
-        self.values = list(range(len(options)))
         self.multiple = multiple
 
+    @property
+    def options(self):
+        '''
+        '''
+
+        p = self.get_prop('options')
+        return SubscriptableTypePropInfo[str,StrTypePropInfo](p)
+
+    @options.setter
+    def options(self, value: Union[SubscriptableTypePropInfo[str,StrTypePropInfo], bool]):
+        '''
+        '''
+        self.set_prop('options', value)
+
     @property
     def currentLabels(self):
         p = self.get_prop('currentLabels')
