@@ -32,7 +32,7 @@ class Fns():
     def map(self,
             key: StrTypePropInfo,
             data: Dict[str, TMapReturn],
-            __default=None) -> TypePropInfo:
+            __default=None) -> StrTypePropInfo:
         assert len(data) > 0, 'dict data len must be greater than 0'
 
         data_value = DictValuePropInfo(None, data)
