@@ -157,6 +157,10 @@ class NumberTypePropInfo(TypePropInfo):
     def __rfloordiv__(self, other: Union[float, int, NumberTypePropInfo]):
         return self // other
 
+    def toString(self):
+        m = MethodPropInfo(self.valuator,self,'toString')
+        return StrTypePropInfo(m)
+
     def _ex_gen_expr(self):
         return ''
 
